/*
Copyright (c) 2006-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description:BmpAnimGuiAppView.cpp 
*/

#include "BmpAnimGui.h"

	
// Animate the balls such that they move across the screen in a sinusoidal pattern
void CExampleAppView::LoadMbmL( const TDesC& aMbmFile )
	{
	// Construct BitmapAnimClientData 
	if( !iAnimFrames )
		{
		CFbsBitmap* bitmap;
		CFbsBitmap* mask;
		CBitmapFrameData* frameGeneral;
		iAnimFrames = CBitmapAnimClientData::NewL();
		CleanupStack::PushL( iAnimFrames );
		
		iX = KColorBallsAnimXDeflectionStart;
		TInt ballIndex = KColorBallsMbmFirstBallIndex;
		
		while( iX < KColorBallsAnimXDeflectionTerminalValue )
			{
			// Load the image
			bitmap = new (ELeave) CFbsBitmap();
			CleanupStack::PushL( bitmap );
			User::LeaveIfError( bitmap->Load(aMbmFile, ballIndex) );		
			ballIndex = ( KColorBallsMbmLastBallIndex == ballIndex ) ? KColorBallsMbmFirstBallIndex : ballIndex + 1;
				
			// Load the mask
			mask = new (ELeave) CFbsBitmap();
			CleanupStack::PushL( mask );
			User::LeaveIfError( mask->Load(aMbmFile, KColorBallsMbmMaskIndex) );		
				
			// Calculate the y deflection
			iY =TInt( KColorBallsAnimYDeflectionOffset + KColorBallsAnimYDeflectionMultiplier*sin( iX ));	
				
			// Construct the frame
			frameGeneral = CBitmapFrameData::NewL( bitmap, mask, KColorBallsAnimFrameDelay, TPoint(iX, iY) );
			CleanupStack::PushL( frameGeneral );
				
			// Add it to the sequence
			iAnimFrames->AppendFrameL( frameGeneral );
				
			// Popping order- mask, bitmap, iFrameGeneral
			CleanupStack::Pop( 3 );	
				
			iX += KColorBallsAnimXDeflectionIncrement;
			}
			
		iBitmapAnimPlayer.SetBitmapAnimDataL( *iAnimFrames );
		CleanupStack::Pop( iAnimFrames );
		}
	}	
	
CExampleAppView::CExampleAppView()
: iBitmapAnimPlayer( iAnimDll ),iAnimDll( iEikonEnv->WsSession() )
  
	{
	}

CExampleAppView* CExampleAppView::NewL(const TRect& aRect)
	{
	CExampleAppView* self = new(ELeave) CExampleAppView();
	CleanupStack::PushL(self);
	self->ConstructL(aRect);
	CleanupStack::Pop();
	return self;
	}

CExampleAppView::~CExampleAppView()
	{
	iBitmapAnimPlayer.Close();
	delete( iAnimFrames );
	iAnimDll.Close();
	delete iExampleText;
	}


// Standard initialisation for a window-owning control.
void CExampleAppView::ConstructL(const TRect& aRect)
	{
	// Fetch the text from the resource file.
	iExampleText = iEikonEnv->AllocReadResourceL( R_EXAMPLE_TEXT_BB );
	
	// The control is window-owning.
	CreateWindowL();
	
	// Extent of the control. 
	SetRect(aRect);
	
	// The control is ready to draw, so notify the UI framework.
	ActivateL();
	
	// Some animation preamble.
	_LIT(KDllName, "BMPANSRV.DLL" );
	User::LeaveIfError( iAnimDll.Load( KDllName ) );
	iBitmapAnimPlayer.ConstructL( Window() );
	
	LoadMbmL( KColorBallsMbmPath );	
	}	
	
					  

// Draws the view with a simple outline rectangle 
void CExampleAppView::Draw(const TRect& /*aRect*/) const
	{
	// Window graphics context
	CWindowGc& gc = SystemGc();
	
	// Area in which we shall draw
	TRect drawRect = Rect();
	
	// The font used for drawing the text
	const CFont* fontUsed;
	
	// Clear the screen
	gc.Clear();
	    
	// Use the title font supplied by the UI
	fontUsed = iEikonEnv->TitleFont();
	gc.UseFont(fontUsed);
	
	// Draw the text in the rectangle and discard the font.
	TInt   baselineOffset=(drawRect.Height() - fontUsed->HeightInPixels())/5; 
	gc.DrawText(*iExampleText,drawRect,baselineOffset,CGraphicsContext::ECenter, 0);
	gc.DiscardFont();		
	}

	
	







	
	





